"""
AWDX Task Module - AI Intents

Defines natural language intents for mapping user queries to task commands.
"""

TASK_INTENTS = [
    {
        "intent": "security_audit",
        "examples": [
            "run a security audit",
            "audit my AWS security",
            "check for security issues",
            "find vulnerabilities in my AWS account",
            "comprehensive security scan",
            "fix safe security issues automatically",
        ],
        "command": "awdx task security-audit",
    },
    {
        "intent": "cost_optimize",
        "examples": [
            "optimize my AWS costs",
            "find cost savings",
            "reduce AWS spending",
            "auto-fix cost issues",
            "show cost optimization opportunities",
        ],
        "command": "awdx task cost-optimize",
    },
    {
        "intent": "compliance_check",
        "examples": [
            "check compliance",
            "run a compliance check",
            "generate a compliance report",
            "am I compliant with SOX",
            "quick compliance scan",
            "compliance status for PCI-DSS",
        ],
        "command": "awdx task compliance-check",
    },
    {
        "intent": "security_monitor",
        "examples": [
            "start security monitoring",
            "monitor my AWS security",
            "enable real-time security alerts",
            "continuous security monitoring",
            "watch for security threats",
        ],
        "command": "awdx task security-monitor",
    },
    {
        "intent": "secret_rotate",
        "examples": [
            "rotate my secrets",
            "auto-rotate AWS secrets",
            "schedule secret rotation",
            "manage secret rotation",
            "rotate a specific secret",
        ],
        "command": "awdx task secret-rotate",
    },
    {
        "intent": "vuln_scan",
        "examples": [
            "scan for vulnerabilities",
            "find security vulnerabilities",
            "vulnerability assessment",
            "security vulnerability scan",
            "auto-remediate vulnerabilities",
            "scan AWS services for vulnerabilities",
        ],
        "command": "awdx task vuln-scan",
    },
    # Phase 2 - Service-Specific Commands
    {
        "intent": "lambda_audit",
        "examples": [
            "audit Lambda functions",
            "check Lambda security",
            "Lambda function audit",
            "review Lambda configurations",
            "Lambda security assessment",
            "audit serverless functions",
        ],
        "command": "awdx task lambda-audit",
    },
    {
        "intent": "lambda_optimize",
        "examples": [
            "optimize Lambda functions",
            "improve Lambda performance",
            "Lambda cost optimization",
            "optimize serverless functions",
            "Lambda memory optimization",
            "reduce Lambda cold starts",
        ],
        "command": "awdx task lambda-optimize",
    },
    {
        "intent": "lambda_monitor",
        "examples": [
            "monitor Lambda functions",
            "Lambda performance monitoring",
            "watch Lambda errors",
            "Lambda cost monitoring",
            "serverless function monitoring",
            "Lambda metrics tracking",
        ],
        "command": "awdx task lambda-monitor",
    },
    {
        "intent": "iam_audit",
        "examples": [
            "audit IAM users and roles",
            "check IAM security",
            "IAM security audit",
            "review IAM permissions",
            "audit AWS access management",
            "IAM compliance check",
        ],
        "command": "awdx task iam-audit",
    },
    {
        "intent": "iam_optimize",
        "examples": [
            "optimize IAM permissions",
            "apply least privilege",
            "IAM access optimization",
            "clean up IAM permissions",
            "optimize AWS access management",
            "IAM credential rotation",
        ],
        "command": "awdx task iam-optimize",
    },
    {
        "intent": "s3_audit",
        "examples": [
            "audit S3 buckets",
            "check S3 security",
            "S3 bucket audit",
            "review S3 configurations",
            "S3 security assessment",
            "audit data storage security",
        ],
        "command": "awdx task s3-audit",
    },
    {
        "intent": "s3_optimize",
        "examples": [
            "optimize S3 storage",
            "S3 cost optimization",
            "optimize S3 access",
            "S3 lifecycle optimization",
            "improve S3 performance",
            "S3 storage class optimization",
        ],
        "command": "awdx task s3-optimize",
    },
    # Phase 3 - Infrastructure Automation Commands
    {
        "intent": "infra_audit",
        "examples": [
            "audit infrastructure",
            "check infrastructure security",
            "CloudFormation audit",
            "infrastructure security assessment",
            "audit CDK templates",
            "infrastructure compliance check",
        ],
        "command": "awdx task infra-audit",
    },
    {
        "intent": "infra_drift",
        "examples": [
            "detect infrastructure drift",
            "check for drift",
            "infrastructure drift detection",
            "remediate infrastructure drift",
            "fix drift issues",
            "drift analysis",
        ],
        "command": "awdx task infra-drift",
    },
    {
        "intent": "infra_cost",
        "examples": [
            "estimate infrastructure costs",
            "infrastructure cost analysis",
            "forecast infrastructure costs",
            "infrastructure cost optimization",
            "cost estimation for infrastructure",
            "infrastructure budget analysis",
        ],
        "command": "awdx task infra-cost",
    },
    {
        "intent": "template_validate",
        "examples": [
            "validate CloudFormation templates",
            "check template security",
            "validate CDK templates",
            "template security validation",
            "infrastructure template validation",
            "check template best practices",
        ],
        "command": "awdx task template-validate",
    },
    {
        "intent": "template_optimize",
        "examples": [
            "optimize CloudFormation templates",
            "optimize CDK templates",
            "template cost optimization",
            "template performance optimization",
            "improve template efficiency",
            "optimize infrastructure templates",
        ],
        "command": "awdx task template-optimize",
    },
    {
        "intent": "template_compliance",
        "examples": [
            "check template compliance",
            "template compliance validation",
            "CloudFormation compliance check",
            "CDK compliance validation",
            "infrastructure template compliance",
            "template security compliance",
        ],
        "command": "awdx task template-compliance",
    },
    {
        "intent": "container_scan",
        "examples": [
            "scan container images",
            "container vulnerability scan",
            "Docker image security scan",
            "container security assessment",
            "scan ECR images",
            "container compliance scan",
        ],
        "command": "awdx task container-scan",
    },
    {
        "intent": "container_audit",
        "examples": [
            "audit container security",
            "container configuration audit",
            "ECS security audit",
            "container permissions audit",
            "audit container networking",
            "container security assessment",
        ],
        "command": "awdx task container-audit",
    },
    {
        "intent": "container_optimize",
        "examples": [
            "optimize container resources",
            "container cost optimization",
            "optimize container scaling",
            "improve container performance",
            "container resource optimization",
            "ECS optimization",
        ],
        "command": "awdx task container-optimize",
    },
    {
        "intent": "k8s_audit",
        "examples": [
            "audit Kubernetes security",
            "EKS security audit",
            "Kubernetes RBAC audit",
            "K8s security assessment",
            "audit Kubernetes pods",
            "Kubernetes compliance audit",
        ],
        "command": "awdx task k8s-audit",
    },
    {
        "intent": "k8s_compliance",
        "examples": [
            "check Kubernetes compliance",
            "EKS compliance check",
            "K8s CIS benchmarks",
            "Kubernetes security compliance",
            "K8s compliance validation",
            "Kubernetes standards check",
        ],
        "command": "awdx task k8s-compliance",
    },
    {
        "intent": "k8s_monitor",
        "examples": [
            "monitor Kubernetes resources",
            "EKS monitoring",
            "K8s performance monitoring",
            "Kubernetes security monitoring",
            "monitor K8s clusters",
            "Kubernetes metrics tracking",
        ],
        "command": "awdx task k8s-monitor",
    },
    {
        "intent": "pipeline_audit",
        "examples": [
            "audit CI/CD pipelines",
            "CodePipeline security audit",
            "pipeline security assessment",
            "audit build pipelines",
            "CI/CD security check",
            "pipeline configuration audit",
        ],
        "command": "awdx task pipeline-audit",
    },
    {
        "intent": "pipeline_optimize",
        "examples": [
            "optimize CI/CD pipelines",
            "pipeline performance optimization",
            "improve pipeline efficiency",
            "pipeline cost optimization",
            "optimize build times",
            "CI/CD optimization",
        ],
        "command": "awdx task pipeline-optimize",
    },
    {
        "intent": "pipeline_monitor",
        "examples": [
            "monitor CI/CD pipelines",
            "pipeline performance monitoring",
            "track pipeline failures",
            "CI/CD metrics monitoring",
            "pipeline execution monitoring",
            "build monitoring",
        ],
        "command": "awdx task pipeline-monitor",
    },
    {
        "intent": "build_optimize",
        "examples": [
            "optimize build processes",
            "CodeBuild optimization",
            "improve build performance",
            "optimize build caching",
            "build efficiency optimization",
            "reduce build times",
        ],
        "command": "awdx task build-optimize",
    },
    {
        "intent": "build_security",
        "examples": [
            "scan build security",
            "CodeBuild security scan",
            "build vulnerability scan",
            "build configuration security",
            "audit build processes",
            "build security assessment",
        ],
        "command": "awdx task build-security",
    },
    {
        "intent": "build_compliance",
        "examples": [
            "check build compliance",
            "CodeBuild compliance check",
            "build security compliance",
            "build standards validation",
            "build compliance audit",
            "CI/CD compliance check",
        ],
        "command": "awdx task build-compliance",
    },
    {
        "intent": "monitoring_setup",
        "examples": [
            "setup monitoring",
            "configure CloudWatch monitoring",
            "automated monitoring setup",
            "monitoring best practices",
            "setup alerts and dashboards",
            "monitoring configuration",
        ],
        "command": "awdx task monitoring-setup",
    },
    {
        "intent": "monitoring_optimize",
        "examples": [
            "optimize monitoring costs",
            "monitoring performance optimization",
            "improve monitoring coverage",
            "CloudWatch optimization",
            "monitoring efficiency",
            "reduce monitoring costs",
        ],
        "command": "awdx task monitoring-optimize",
    },
    {
        "intent": "monitoring_compliance",
        "examples": [
            "check monitoring compliance",
            "monitoring standards validation",
            "CloudWatch compliance check",
            "monitoring security compliance",
            "audit monitoring configurations",
            "monitoring compliance assessment",
        ],
        "command": "awdx task monitoring-compliance",
    },
    {
        "intent": "alert_configure",
        "examples": [
            "configure alerts",
            "setup intelligent alerts",
            "alert configuration",
            "automated alert setup",
            "configure alert thresholds",
            "alert escalation setup",
        ],
        "command": "awdx task alert-configure",
    },
    {
        "intent": "alert_optimize",
        "examples": [
            "optimize alerts",
            "reduce alert noise",
            "improve alert coverage",
            "alert optimization",
            "optimize alert response",
            "alert efficiency improvement",
        ],
        "command": "awdx task alert-optimize",
    },
    {
        "intent": "network_audit",
        "examples": [
            "audit network security",
            "VPC security audit",
            "network configuration audit",
            "security group audit",
            "network ACL audit",
            "network security assessment",
        ],
        "command": "awdx task network-audit",
    },
    {
        "intent": "network_optimize",
        "examples": [
            "optimize network configuration",
            "network performance optimization",
            "VPC optimization",
            "network cost optimization",
            "optimize network routing",
            "network efficiency improvement",
        ],
        "command": "awdx task network-optimize",
    },
    {
        "intent": "network_monitor",
        "examples": [
            "monitor network traffic",
            "network anomaly detection",
            "VPC monitoring",
            "network compliance monitoring",
            "network security monitoring",
            "traffic analysis",
        ],
        "command": "awdx task network-monitor",
    },
    {
        "intent": "sg_audit",
        "examples": [
            "audit security groups",
            "security group rules audit",
            "SG compliance check",
            "security group assessment",
            "audit firewall rules",
            "security group validation",
        ],
        "command": "awdx task sg-audit",
    },
    {
        "intent": "sg_optimize",
        "examples": [
            "optimize security groups",
            "security group optimization",
            "optimize firewall rules",
            "SG rules optimization",
            "improve security coverage",
            "security group efficiency",
        ],
        "command": "awdx task sg-optimize",
    },
    {
        "intent": "sg_compliance",
        "examples": [
            "check security group compliance",
            "SG compliance validation",
            "security group standards check",
            "firewall compliance audit",
            "security group compliance assessment",
            "SG security compliance",
        ],
        "command": "awdx task sg-compliance",
    },
]
